@@ -7,25 +7,23 @@ Geo::Constants - Perl Standard Geo:: package for constants
 
 =head1 SYNOPSIS
 
-  use Geo::Constants qw{pi};         #import into namespace
-  print "PI: ", pi, "\n";
+  use Geo::Constants qw{PI DEG RAD}; #import into namespace
+  print "PI: ", PI, "\n";
 
   use Geo::Constants;                #Perl OO
   my $obj = Geo::Constants->new();
-  print "PI: ", $obj->pi, "\n";
+  print "PI: ", $obj->PI, "\n";
 
 =head1 DESCRIPTION
 
-This module is a pure Perl port of the NGS program in the public domain "forward" by Robert (Sid) Safford and Stephen J. Frakes.  
-
-
 =cut
 
 use strict;
-use vars qw($VERSION $PACKAGE @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
+#use vars qw($VERSION $PACKAGE @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
+use vars qw($VERSION @ISA @EXPORT_OK);
 @ISA = qw(Exporter);
-@EXPORT_OK = (qw{pi});
-$VERSION = sprintf("%d.%02d", q{Revision: 0.01} =~ /(\d+)\.(\d+)/);
+@EXPORT_OK = (qw{PI DEG RAD});
+$VERSION = sprintf("%d.%02d", q{Revision: 0.02} =~ /(\d+)\.(\d+)/);
 
 =head1 CONSTRUCTOR
 
@@ -34,7 +32,7 @@ $VERSION = sprintf("%d.%02d", q{Revision: 0.01} =~ /(\d+)\.(\d+)/);
 The new() constructor
 
   my $obj = Geo::Constants->new();
-    
+
 =cut
 
 sub new {
@@ -55,13 +53,41 @@ sub initialize {
   my $param = shift();
 }
 
-=head2 pi
+=head2 PI
 
-  my $pi = $obj->pi;
+  my $pi = $obj->PI;
 
 =cut
 
-sub pi {return 4 * atan2(1,1);}
+#use constant PI => 4 * atan2(1,1);
+
+sub PI {
+  return 4 * atan2(1,1); #Perl should complile this as a constant
+}
+
+=head2 DEG
+
+  my $degress_per_radian = $obj->DEG;
+
+=cut
+
+#use constant DEG => 180 / PI;
+sub DEG {
+  return(180 / &PI); #Degrees per radian
+}
+
+=head2 RAD
+
+  my $radians_per_degree = $obj->RAD;
+
+=cut
+
+#use constant RAD => PI / 180;
+sub RAD {
+  return(&PI / 180); #Radians per degree
+}
+
+use subs @EXPORT_OK;
 
 1;
 
@@ -81,6 +107,8 @@ Michael R. Davis qw/perl michaelrdavis com/
 
 =head1 LICENSE
 
+Copyright (c) 2006 Michael R. Davis (mrdvt92)
+
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
